@@ -34,3 +34,11 @@ model_get_xlevels.lmerMod <- function(model) {
 #' @export
 #' @rdname model_get_xlevels
 model_get_xlevels.glmerMod <- model_get_xlevels.lmerMod
+
+#' @export
+#' @rdname model_get_xlevels
+model_get_xlevels.felm <- model_get_xlevels.lmerMod
+
+#' @export
+#' @rdname model_get_xlevels
+model_get_xlevels.brmsfit <- model_get_xlevels.lmerMod
