@@ -11,6 +11,15 @@ library(gtsummary)
 library(ggplot2)
 library(dplyr)
 
+# paged_table() was introduced only in rmarkdwon v1.2
+print_table <- function(tab) {
+  if (packageVersion("rmarkdown") >= 1.2) {
+    rmarkdown::paged_table(tab)
+  } else {
+    knitr::kable(tab)
+  }
+}
+
 ## -----------------------------------------------------------------------------
 model_logit <- glm(response ~ trt + grade, trial, family = binomial)
 broom::tidy(model_logit)
@@ -67,9 +76,9 @@ options(knitr.kable.NA = '')
 tidy_table %>%
   # format model estimates
   select(label, estimate, conf.low, conf.high, p.value) %>%
-  mutate_at(vars(estimate, conf.low, conf.high), style_ratio) %>%
-  mutate_at(vars(p.value), style_pvalue) %>%
-  knitr::kable()
+  mutate(across(all_of(c("estimate", "conf.low", "conf.high")), style_ratio)) %>%
+  mutate(across(p.value, style_pvalue)) %>%
+  print_table()
 
 ## -----------------------------------------------------------------------------
 model_logit %>%
@@ -78,7 +87,7 @@ model_logit %>%
 ## -----------------------------------------------------------------------------
 model_logit %>%
   tidy_plus_plus(exponentiate = TRUE) %>%
-  rmarkdown::paged_table()
+  print_table()
 
 ## -----------------------------------------------------------------------------
 model_poly <- glm(response ~ poly(age, 3) + ttdeath, na.omit(trial), family = binomial)
@@ -89,7 +98,7 @@ model_poly %>%
     add_header_rows = TRUE,
     variable_labels = c(age = "Age in years")
   ) %>%
-  rmarkdown::paged_table()
+  print_table()
 
 ## -----------------------------------------------------------------------------
 model_1 <- glm(
@@ -103,7 +112,7 @@ model_1 %>%
   tidy_add_reference_rows() %>%
   tidy_add_estimate_to_reference_rows(exponentiate = TRUE) %>%
   tidy_add_term_labels() %>%
-  rmarkdown::paged_table()
+  print_table()
 
 ## -----------------------------------------------------------------------------
 model_2 <- glm(
@@ -122,7 +131,7 @@ model_2 %>%
   tidy_add_reference_rows() %>%
   tidy_add_estimate_to_reference_rows(exponentiate = TRUE) %>%
   tidy_add_term_labels() %>%
-  rmarkdown::paged_table()
+  print_table()
 
 ## -----------------------------------------------------------------------------
 model_3 <- glm(
@@ -141,7 +150,7 @@ model_3 %>%
   tidy_add_reference_rows() %>%
   tidy_add_estimate_to_reference_rows(exponentiate = TRUE) %>%
   tidy_add_term_labels() %>%
-  rmarkdown::paged_table()
+  print_table()
 
 ## -----------------------------------------------------------------------------
 model_4 <- glm(
@@ -160,29 +169,50 @@ model_4 %>%
   tidy_add_reference_rows() %>%
   tidy_add_estimate_to_reference_rows(exponentiate = TRUE) %>%
   tidy_add_term_labels() %>%
-  rmarkdown::paged_table()
+  print_table()
 
 ## ---- echo=FALSE--------------------------------------------------------------
 tibble::tribble(
   ~Column, ~Function, ~Description,
+  'original_term', '`tidy_disambiguate_terms()`', 'Original term before disambiguation. This columns is added only when disambiguation is needed (i.e. for mixed models).',
   'variable', '`tidy_identify_variables()`', 'String of variable names from the model. For categorical variables and polynomial terms defined with `stats::poly()`, terms belonging to the variable are identified.',
   'var_class', '`tidy_identify_variables()`', "Class of the variable.",
-  'var_type', '`tidy_identify_variables()`', "One of 'intercept', 'continuous', 'dichotomous', 'categorical', or 'interaction'",
+  'var_type', '`tidy_identify_variables()`', "One of 'intercept', 'continuous', 'dichotomous', 'categorical', 'interaction', 'ran_pars' or 'ran_vals'",
   'var_nlevels', '`tidy_identify_variables()`', "Number of original levels for categorical variables",
   'contrasts', '`tidy_add_contrasts()`', "Contrasts used for categorical variables.<br /><em>Require 'variable' column. If needed, will automatically apply `tidy_identify_variables()`.</em>",
-  'contrasts_type', '`tidy_add_contrasts()`', "Type of contrasts ('treatment', 'sum', 'poly', 'helmert' or 'other')",
+  'contrasts_type', '`tidy_add_contrasts()`', "Type of contrasts ('treatment', 'sum', 'poly', 'helmert', 'other' or 'no.contrast')",
   'reference_row', '`tidy_add_reference_rows()`', "Logical indicating if a row is a reference row for categorical variables using a treatment or a sum contrast. Is equal to `NA` for variables who do not have a reference row.<br /><em>Require 'contrasts' column. If needed, will automatically apply `tidy_add_contrasts()`.<br />`tidy_add_reference_rows()` will not populate the label of the reference term. It is therefore better to apply `tidy_add_term_labels()` after `tidy_add_reference_rows()` rather than before.</em>",
   'var_label', '`tidy_add_variable_labels()`', "String of variable labels from the model. Columns labelled with the `labelled` package are retained. It is possible to pass a custom label for an interaction term with the `labels` argument. <br /><em>Require 'variable' column. If needed, will automatically apply `tidy_identify_variables()`.",
   'label', '`tidy_add_term_labels()`', "String of term labels based on (1) labels provided in `labels` argument if provided; (2) factor levels for categorical variables coded with treatment, SAS or sum contrasts; (3) variable labels when there is only one term per variable; and (4) term name otherwise.<br /><em>Require 'variable_label' column. If needed, will automatically apply `tidy_add_variable_labels()`.<br />Require 'contrasts' column. If needed, will automatically apply `tidy_add_contrasts()`.</em>",
-  'header_row', '`tidy_add_header_rows()`', "Logical indicating if a row is a header row for variables with several terms. Is equal to `NA` for variables who do not have an header row.</br><em>Require 'label' column. If needed, will automatically apply `tidy_add_term_labels()`.<br />It is better to apply `tidy_add_header_rows()` after other `tidy_*` functions</em>"
-  
-  
+  'header_row', '`tidy_add_header_rows()`', "Logical indicating if a row is a header row for variables with several terms. Is equal to `NA` for variables who do not have an header row.</br><em>Require 'label' column. If needed, will automatically apply `tidy_add_term_labels()`.<br />It is better to apply `tidy_add_header_rows()` after other `tidy_*` functions</em>",
+  'n_obs', '`tidy_add_n()`', 'Number of observations',
+  'n_event', '`tidy_add_n()`', 'Number of events (for binomial and multinomial logistic models, Poisson and Cox models)',
+  'exposure', '`tidy_add_n()`', 'Exposure time (for Poisson and Cox models)'
 ) %>%
     gt::gt() %>%
   gt::fmt_markdown(columns = TRUE) %>%
   gt::tab_options(
-    column_labels.font.weight = "bold",
-    
+    column_labels.font.weight = "bold"
+  ) %>%
+  gt::opt_row_striping() %>%
+  gt::tab_style("vertical-align:top; font-size: 12px;", gt::cells_body())
+
+## ---- echo=FALSE--------------------------------------------------------------
+tibble::tribble(
+  ~Attribute, ~Function, ~Description,
+  'exponentiate', '`tidy_and_attach()`', 'Indicates if estimates were exponentiated',
+  'coefficients_type', '`tidy_add_coefficients_type()`', 'Type of coefficients',
+  'coefficients_label', '`tidy_add_coefficients_type()`', 'Coefficients label',
+  'variable_labels', '`tidy_add_variable_labels()`', 'Custom variable labels passed to `tidy_add_variable_labels()`',
+  'term_labels', '`tidy_add_term_labels()`', 'Custom term labels passed to `tidy_add_term_labels()`',
+  'N_obs', '`tidy_add_n()`', 'Total number of observations',
+  'N_event', '`tidy_add_n()`', 'Total number of events',
+  'Exposure', '`tidy_add_n()`', 'Total of exposure time'
+) %>%
+    gt::gt() %>%
+  gt::fmt_markdown(columns = TRUE) %>%
+  gt::tab_options(
+    column_labels.font.weight = "bold"
   ) %>%
   gt::opt_row_striping() %>%
   gt::tab_style("vertical-align:top; font-size: 12px;", gt::cells_body())
@@ -201,8 +231,10 @@ tibble::tribble(
   '`lme4::lmer()`', '`broom.mixed` package required',
   '`lme4::glmer()`', '`broom.mixed` package required',
   '`lme4::glmer.nb()`', '`broom.mixed` package required',
+  '`brms::brm()`', '`broom.mixed` package required',
   '`geepack::geeglm()`', '',
   '`gam::gam()`', '',
+  '`mgcv::gam()`', 'Use default tidier `broom::tidy()` for smooth terms only, or `gtsummary::tidy_gam()` to include parametric terms',
   '`nnet::multinom()`', '',
   '`survey::svyglm()`', '',
   '`survey::svycoxph()`', '',
@@ -210,7 +242,10 @@ tibble::tribble(
   '`MASS::polr()`', '',
   '`MASS::glm.nb()`', '',
   '`mice::mira`', 'Limited support. If `mod` is a `mira` object, use `tidy_plus_plus(mod, tidy_fun = function(x, ...) mice::pool(x) %>% mice::tidy(...))`',
-  '`lavaan::lavaan()`', 'Limited support for categorical variables'
+  '`lavaan::lavaan()`', 'Limited support for categorical variables',
+  '`cmprsk::crr()`', 'Limited support',
+  '`stats::nls()`', 'Limited support',
+  '`lfe::felm()`', ''
 ) %>%
   dplyr::arrange(Model) %>%
   gt::gt() %>%
