@@ -95,13 +95,20 @@ test_that("test tidy_add_reference_rows() checks", {
       tidy_add_reference_rows()
   )
 
-  # warning if applied after tidy_add_term_labels()
+  # message if applied after tidy_add_term_labels()
   expect_message(
     mod %>% tidy_and_attach() %>%
       tidy_add_term_labels() %>%
       tidy_add_reference_rows()
   )
 
+  # message if applied after tidy_add_n()
+  expect_message(
+    mod %>% tidy_and_attach() %>%
+      tidy_add_n() %>%
+      tidy_add_reference_rows()
+  )
+
   # error if applied after tidy_add_header_rows()
   expect_error(
     mod %>% tidy_and_attach() %>%
