@@ -18,14 +18,38 @@ test_that("tidy_plus_plus() works for basic models", {
     c("T Stage:T2/T1", "T Stage:T3/T1", "T Stage:T4/T1", "custom:II/I",
       "custom:III/I", "Chemotherapy Treatment:Drug B/Drug A")
   )
+
+  # works with add_n
+  res <- mod %>% tidy_plus_plus(add_n = TRUE)
+  expect_true(all(c("n_obs", "n_event") %in% names(res)))
 })
 
+test_that("tidy_plus_plus() works with no intercept models", {
+  mod <- glm(response ~ stage + grade - 1, data = gtsummary::trial, family = binomial)
+  expect_error(
+    res <- mod %>% tidy_plus_plus(),
+    NA
+  )
+  expect_equivalent(
+    res$variable,
+    c("stage", "stage", "stage", "stage", "grade", "grade", "grade")
+  )
+  expect_equivalent(
+    res$label,
+    c("T1", "T2", "T3", "T4", "I", "II", "III")
+  )
+  expect_equivalent(
+    res$contrasts_type,
+    c("no.contrast", "no.contrast", "no.contrast", "no.contrast",
+      "treatment", "treatment", "treatment")
+  )
+})
 
 test_that("tidy_plus_plus() and functionnal programming", {
   # works with glm
   expect_error(
     res <- dplyr::tibble(grade = c("I", "II", "III")) %>%
-      dplyr::mutate(df_model = purrr:::map(grade, ~ gtsummary::trial %>% dplyr::filter(grade == ..1))) %>%
+      dplyr::mutate(df_model = purrr::map(grade, ~ gtsummary::trial %>% dplyr::filter(grade == ..1))) %>%
       dplyr::mutate(
         mv_formula_char = "response ~ trt + age + marker",
         mv_formula = purrr::map(mv_formula_char, ~ as.formula(.x)),
@@ -47,30 +71,34 @@ test_that("tidy_plus_plus() and functionnal programming", {
   # will display a message
   # but a result should be returned
   expect_message(
-    res <- dplyr::tibble(grade = c("I", "II", "III")) %>%
-      dplyr::mutate(df_model = purrr:::map(grade, ~ gtsummary::trial %>% dplyr::filter(grade == ..1))) %>%
-      dplyr::mutate(
-        mv_formula_char = "survival::Surv(ttdeath, death) ~ trt + age + marker",
-        mv_formula = purrr::map(mv_formula_char, ~ as.formula(.x)),
-        mv_model_form =
-          purrr::map2(
-            mv_formula, df_model,
-            ~ survival::coxph(..1, data = ..2)
-          ),
-        mv_tbl_form =
-          purrr::map(
-            mv_model_form,
-            ~ tidy_plus_plus(..1, exponentiate = TRUE)
-          )
-      )
+    suppressWarnings(
+      res <- dplyr::tibble(grade = c("I", "II", "III")) %>%
+        dplyr::mutate(df_model = purrr::map(grade, ~ gtsummary::trial %>% dplyr::filter(grade == ..1))) %>%
+        dplyr::mutate(
+          mv_formula_char = "survival::Surv(ttdeath, death) ~ trt + age + marker",
+          mv_formula = purrr::map(mv_formula_char, ~ as.formula(.x)),
+          mv_model_form =
+            purrr::map2(
+              mv_formula, df_model,
+              ~ survival::coxph(..1, data = ..2)
+            ),
+          mv_tbl_form =
+            purrr::map(
+              mv_model_form,
+              ~ tidy_plus_plus(..1, exponentiate = TRUE)
+            )
+        )
+    )
   )
+
 })
 
 
 test_that("tidy_plus_plus() with mice objects", {
+  skip_if(packageVersion("mice") < "3.12.0")
   # impute missing values
   imputed_trial <-
-    suppressWarnings(mice::mice(gtsummary::trial, maxit = 2, m = 2))
+    suppressWarnings(mice::mice(gtsummary::trial, maxit = 2, m = 2, print = FALSE))
   # build regression model
   mod <- with(imputed_trial, lm(age ~ marker + grade))
 
@@ -129,6 +157,7 @@ test_that("tidy_plus_plus() works with stats::aov", {
 })
 
 test_that("tidy_plus_plus() works with lme4::lmer", {
+  skip_if_not_installed("lme4")
   mod <- lme4::lmer(Reaction ~ Days + (Days | Subject), lme4::sleepstudy)
   skip_if_not_installed("broom.mixed")
   expect_error(
@@ -139,6 +168,7 @@ test_that("tidy_plus_plus() works with lme4::lmer", {
 
 
 test_that("tidy_plus_plus() works with lme4::glmer", {
+  skip_if_not_installed("lme4")
   mod <- lme4::glmer(cbind(incidence, size - incidence) ~ period + (1 | herd),
                      family = binomial, data = lme4::cbpp
   )
@@ -158,16 +188,12 @@ test_that("tidy_plus_plus() works with lme4::glmer", {
 
 
 test_that("tidy_plus_plus() works with lme4::glmer.nb", {
-  dd <- expand.grid(
-    f1 = factor(1:3),
-    f2 = LETTERS[1:2], g = 1:9, rep = 1:15,
-    KEEP.OUT.ATTRS = FALSE
-  )
-  mu <- 5*(-4 + with(dd, as.integer(f1) + 4*as.numeric(f2)))
-  dd$y <- rnbinom(nrow(dd), mu = mu, size = 0.5)
   skip_if_not_installed("lme4")
+  skip_if_not_installed("MASS")
   library(lme4)
-  mod <- lme4::glmer.nb(y ~ f1*f2 + (1|g), data = dd)
+  suppressMessages(
+    mod <- lme4::glmer.nb(Days ~ Age + Eth + (1|Sex), data = MASS::quine)
+  )
   skip_if_not_installed("broom.mixed")
   expect_error(
     res <- mod %>% tidy_plus_plus(),
@@ -215,7 +241,12 @@ test_that("tidy_plus_plus() works with survival::clogit", {
 
 
 test_that("tidy_plus_plus() works with nnet::multinom", {
-  mod <- nnet::multinom(grade ~ stage + marker + age, data = gtsummary::trial, trace = FALSE)
+  suppressMessages(
+    mod <- nnet::multinom(
+      grade ~ stage + marker + age, data = gtsummary::trial,
+      trace = FALSE
+    )
+  )
   expect_error(
     res <- mod %>% tidy_plus_plus(),
     NA
@@ -281,12 +312,14 @@ test_that("tidy_plus_plus() works with MASS::polr", {
 test_that("tidy_plus_plus() works with MASS::glm.nb", {
   mod <- MASS::glm.nb(Days ~ Sex / (Age + Eth * Lrn), data = MASS::quine)
   expect_error(
-    res <- mod %>% tidy_plus_plus(),
+    suppressWarnings(res <- mod %>% tidy_plus_plus()),
     NA
   )
 })
 
 test_that("tidy_plus_plus() works with geepack::geeglm", {
+  skip_if(packageVersion("geepack") < 1.3)
+
   df <- geepack::dietox
   df$Cu <- as.factor(df$Cu)
   mf <- formula(Weight ~ Cu * Time)
@@ -310,6 +343,48 @@ test_that("tidy_plus_plus() works with gam::gam", {
 })
 
 
+test_that("tidy_plus_plus() works with brms::brm", {
+  skip_if_not_installed("broom.mixed")
+  skip_if_not_installed("brms")
+  skip_if(packageVersion("brms") < 2.13)
+
+  load(system.file("extdata", "brms_example.rda", package="broom.mixed"))
+  mod <- brms_crossedRE
+  expect_error(
+    res <- mod %>% tidy_plus_plus(),
+    NA
+  )
+})
+
+test_that("tidy_plus_plus() works with cmprsk::crr", {
+  skip_if_not_installed("cmprsk")
+  skip_if(packageVersion("broom") < "0.7.4")
+
+  ftime <- rexp(200)
+  fstatus <- sample(0:2,200,replace=TRUE)
+  cov <- matrix(runif(600),nrow=200)
+  dimnames(cov)[[2]] <- c('x1','x2','x3')
+  mod <- cmprsk::crr(ftime,fstatus,cov)
+  expect_error(
+    res <- mod %>% tidy_plus_plus(quiet = TRUE),
+    NA
+  )
+})
+
+
+test_that("tidy_plus_plus() works with stats::nls", {
+  mod <- stats::nls(
+    Petal.Width ~ a * Petal.Length - (Sepal.Width + Sepal.Length) / b + a^2,
+    data = iris,
+    start = list(a = 1, b = 1)
+  )
+  expect_error(
+    res <- mod %>% tidy_plus_plus(),
+    NA
+  )
+})
+
+
 test_that("tidy_plus_plus() works with lavaan::lavaan", {
   df <- lavaan::HolzingerSwineford1939
   df$grade <- factor(df$grade, ordered = TRUE)
@@ -327,6 +402,17 @@ test_that("tidy_plus_plus() works with lavaan::lavaan", {
   )
 })
 
+
+test_that("tidy_plus_plus() works with lfe::felm", {
+  skip_if_not_installed("lfe")
+  mod <- lfe::felm(marker ~ age + grade | stage | 0, gtsummary::trial)
+  expect_error(
+    res <- mod %>% tidy_plus_plus(),
+    NA
+  )
+})
+
+
 test_that("tidy_plus_plus() error messaging", {
   # does not allow for exponentiate, conf.inf, conf.level arguments
   bad_tidy <- function(x) {
@@ -339,3 +425,35 @@ test_that("tidy_plus_plus() error messaging", {
   )
 })
 
+
+test_that("tidy_plus_plus() works with mgcv::gam", {
+  tidy_gam <- function(x, conf.int = FALSE, exponentiate = FALSE, ...) {
+    broom::tidy(x,
+                conf.int = conf.int,
+                exponentiate = exponentiate,
+                parametric = TRUE,  ...) %>%
+      dplyr::mutate(parametric = TRUE) %>%
+      dplyr::bind_rows(
+        broom::tidy(x, parametric = FALSE, ...) %>%
+          dplyr::mutate(parametric = FALSE)
+      ) %>%
+      dplyr::relocate(.data$parametric, .after = dplyr::last_col())
+  }
+
+  gam_logistic <- mgcv::gam(response ~ s(marker, ttdeath) + grade + age, data = gtsummary::trial, family = binomial)
+  gam_linear <- mgcv::gam(response ~ s(marker, ttdeath) + grade, data = gtsummary::trial)
+  gam_smooth_only <- mgcv::gam(response ~ s(marker, ttdeath), data = gtsummary::trial)
+  gam_param_only <- mgcv::gam(response ~ grade, data = gtsummary::trial)
+
+  expect_error(tbl_gam_logistic <- gam_logistic %>% tidy_plus_plus(tidy_fun = tidy_gam), NA)
+  expect_error(gam_logistic %>% tidy_plus_plus(), NA)
+
+  expect_error(tbl_gam_linear <- gam_linear %>% tidy_plus_plus(tidy_fun = tidy_gam), NA)
+  expect_error(gam_linear %>% tidy_plus_plus(), NA)
+
+  expect_error(tbl_gam_smooth_only <- gam_smooth_only %>% tidy_plus_plus(tidy_fun = tidy_gam), NA)
+  expect_error(gam_smooth_only %>% tidy_plus_plus(), NA)
+
+  expect_error(tbl_gam_param_only <- gam_param_only %>% tidy_plus_plus(tidy_fun = tidy_gam), NA)
+  # the default tidier return a df with no columns and no rows...it fails.
+})
